@@ -7,13 +7,13 @@ use base qw(Exporter);
 @JSON::EXPORT = qw(from_json to_json jsonToObj objToJson encode_json decode_json);
 
 BEGIN {
-    $JSON::VERSION = '2.11';
+    $JSON::VERSION = '2.13';
     $JSON::DEBUG   = 0 unless (defined $JSON::DEBUG);
 }
 
 my $Module_XS  = 'JSON::XS';
 my $Module_PP  = 'JSON::PP';
-my $XS_Version = '2.21';
+my $XS_Version = '2.22';
 
 
 # XS and PP common methods
@@ -1275,8 +1275,8 @@ Converts the given Perl data structure (a simple scalar or a reference
 to a hash or array) to its JSON representation. Simple scalars will be
 converted into JSON string or number sequences, while references to arrays
 become JSON arrays and references to hashes become JSON objects. Undefined
-Perl values (e.g. C<undef>) become JSON C<null> values. Neither C<true>
-nor C<false> values will be generated.
+Perl values (e.g. C<undef>) become JSON C<null> values.
+References to the integers C<0> and C<1> are converted into C<true> and C<false>.
 
 =head2 decode
 
@@ -1287,7 +1287,8 @@ returning the resulting simple scalar or reference. Croaks on error.
 
 JSON numbers and strings become simple Perl scalars. JSON arrays become
 Perl arrayrefs and JSON objects become Perl hashrefs. C<true> becomes
-C<1>, C<false> becomes C<0> and C<null> becomes C<undef>.
+C<1> (C<JSON::true>), C<false> becomes C<0> (C<JSON::false>) and
+C<null> becomes C<undef>.
 
 =head2 decode_prefix
 
@@ -1711,6 +1712,10 @@ objects into JSON numbers.
 
 =back
 
+=head1 JSON and ECMAscript
+
+See to L<JSON::XS/JSON and ECMAscript>.
+
 =head1 JSON and YAML
 
 JSON is not a subset of YAML.
@@ -1783,7 +1788,7 @@ But If you C<use> C<JSON> passing the optional string C<-support_by_pp>,
 it makes a part of those unupported methods available.
 This feature is achieved by using JSON::PP in C<de/encode>.
 
-   BEING { $ENV{PERL_JSON_BACKEND} = 2 } # with JSON::XS
+   BEGIN { $ENV{PERL_JSON_BACKEND} = 2 } # with JSON::XS
    use JSON -support_by_pp;
    my $json = new JSON;
    $json->allow_nonref->escape_slash->encode("/");
