@@ -5,9 +5,10 @@ use strict;
 
 my @properties;
 
-$JSON::PP56::VERSION = '1.05';
+$JSON::PP56::VERSION = '1.07';
 
 BEGIN {
+
     sub utf8::is_utf8 {
         my $len =  length $_[0]; # char length
         {
@@ -22,12 +23,12 @@ BEGIN {
     }
 
 
-    sub utf8::downgrade (\$;$) {
-        return 1 unless ( utf8::is_utf8( ${$_[0]} ) );
+    sub utf8::downgrade ($;$) {
+        return 1 unless ( utf8::is_utf8( $_[0] ) );
 
-        if ( _is_valid_utf8(${$_[0]}) ) {
+        if ( _is_valid_utf8( $_[0] ) ) {
             my $downgrade;
-            for my $c ( unpack("U*", ${$_[0]}) ) {
+            for my $c ( unpack( "U*", $_[0] ) ) {
                 if ( $c < 256 ) {
                     $downgrade .= pack("C", $c);
                 }
@@ -35,7 +36,7 @@ BEGIN {
                     $downgrade .= pack("U", $c);
                 }
             }
-            ${$_[0]} = $downgrade;
+            $_[0] = $downgrade;
             return 1;
         }
         else {
@@ -45,26 +46,21 @@ BEGIN {
     }
 
 
-    sub utf8::encode (\$) { # UTF8 flag off
-        if ( utf8::is_utf8( ${$_[0]} ) ) {
-            ${$_[0]} = pack( "C*", unpack( "C*", ${$_[0]} ) );
+    sub utf8::encode ($) { # UTF8 flag off
+        if ( utf8::is_utf8( $_[0] ) ) {
+            $_[0] = pack( "C*", unpack( "C*", $_[0] ) );
         }
         else {
-            ${$_[0]} = pack( "U*", map {
-                if ( $_ > 127 ) {
-                    unpack ( "C*", pack("U*", $_) );
-                }
-                else {
-                    $_;
-                }
-            } unpack( "C*", ${$_[0]} ) );
+            $_[0] = pack( "U*", unpack( "C*", $_[0] ) );
+            $_[0] = pack( "C*", unpack( "C*", $_[0] ) );
         }
     }
 
 
-    sub utf8::decode (\$) { # UTF8 flag on
-        if ( _is_valid_utf8(${$_[0]}) ) {
-            ${$_[0]} = pack("U*", unpack("U*", ${$_[0]}));
+    sub utf8::decode ($) { # UTF8 flag on
+        if ( _is_valid_utf8( $_[0] ) ) {
+            utf8::downgrade( $_[0] );
+            $_[0] = pack( "U*", unpack( "U*", $_[0] ) );
         }
     }
 
@@ -73,6 +69,11 @@ BEGIN {
     *JSON::PP::JSON_PP_encode_latin1     = \&_encode_latin1;
     *JSON::PP::JSON_PP_decode_surrogates = \&JSON::PP::_decode_surrogates;
     *JSON::PP::JSON_PP_decode_unicode    = \&JSON::PP::_decode_unicode;
+
+    unless ( defined &B::SVp_NOK ) { # missing in B module.
+        eval q{ sub B::SVp_NOK () { 0x02000000; } };
+    }
+
 }
 
 
@@ -142,15 +143,13 @@ sub _is_valid_utf8 {
 }
 
 
-sub JSON::PP::incr_parse { #require JSON::PP::IncrParser;
+sub JSON::PP::incr_parse {
     local $Carp::CarpLevel = 1;
     ( $_[0]->{_incr_parser} ||= JSON::PP::IncrParser->new )->incr_parse( @_ );
 }
 
 
-sub JSON::PP::incr_text : lvalue { #require JSON::PP::IncrParser;
-#    ( $_[0]->{_incr_parser} ||= JSON::PP::IncrParser->new )->incr_text;
-#    my $incr_parse = ( $_[0]->{_incr_parser} ||= JSON::PP::IncrParser->new );
+sub JSON::PP::incr_text : lvalue {
     $_[0]->{_incr_parser} ||= JSON::PP::IncrParser->new;
 
     if ( $_[0]->{_incr_parser}->{incr_parsing} ) {
@@ -160,11 +159,16 @@ sub JSON::PP::incr_text : lvalue { #require JSON::PP::IncrParser;
 }
 
 
-sub JSON::PP::incr_skip { #require JSON::PP::IncrParser;
+sub JSON::PP::incr_skip {
     ( $_[0]->{_incr_parser} ||= JSON::PP::IncrParser->new )->incr_skip;
 }
 
 
+sub JSON::PP::incr_reset {
+    ( $_[0]->{_incr_parser} ||= JSON::PP::IncrParser->new )->incr_reset;
+}
+
+
 1;
 __END__
 
